@@ -1,5 +1,22 @@
 var NAVTREEINDEX11 =
 {
+"classzypp_1_1CapDetail.html#af0ff223e378d4998856e395e91f9cfbfac129043324923c63f60030bfc05b834e":[3,0,10,66,1,3],
+"classzypp_1_1CapDetail.html#af0ff223e378d4998856e395e91f9cfbfac129043324923c63f60030bfc05b834e":[4,0,7,57,1,3],
+"classzypp_1_1CapDetail.html#afbd97ef715bff233961210e3de027546":[3,0,10,66,8],
+"classzypp_1_1CapDetail.html#afbd97ef715bff233961210e3de027546":[4,0,7,57,8],
+"classzypp_1_1CapDetail.html#afccb071dd10a5eda8810ad96ee34dd71":[3,0,10,66,10],
+"classzypp_1_1CapDetail.html#afccb071dd10a5eda8810ad96ee34dd71":[4,0,7,57,10],
+"classzypp_1_1CapMatch.html":[3,0,10,67],
+"classzypp_1_1CapMatch.html":[4,0,7,58],
+"classzypp_1_1CapMatch.html#a0f39ffa453576789aff52df3adeb3c5a":[3,0,10,67,4],
+"classzypp_1_1CapMatch.html#a0f39ffa453576789aff52df3adeb3c5a":[4,0,7,58,4],
+"classzypp_1_1CapMatch.html#a149620ad0c46ae8cae3a95325e46c25f":[3,0,10,67,3],
+"classzypp_1_1CapMatch.html#a149620ad0c46ae8cae3a95325e46c25f":[4,0,7,58,3],
+"classzypp_1_1CapMatch.html#a2e2eeda9fc9b012771b07c6d604fbdae":[3,0,10,67,13],
+"classzypp_1_1CapMatch.html#a2e2eeda9fc9b012771b07c6d604fbdae":[4,0,7,58,13],
+"classzypp_1_1CapMatch.html#a31d9dfc9d32aeccf9ae4b25c06eaae63":[3,0,10,67,11],
+"classzypp_1_1CapMatch.html#a31d9dfc9d32aeccf9ae4b25c06eaae63":[4,0,7,58,11],
+"classzypp_1_1CapMatch.html#a4187cc7d4cac031ab25dc84776673dab":[3,0,10,665],
 "classzypp_1_1CapMatch.html#a4187cc7d4cac031ab25dc84776673dab":[3,0,10,67,9],
 "classzypp_1_1CapMatch.html#a4187cc7d4cac031ab25dc84776673dab":[4,0,7,58,9],
 "classzypp_1_1CapMatch.html#a5a1754331f3a54a45a20413e723bd0e0":[3,0,10,67,12],
@@ -40,7 +57,7 @@ var NAVTREEINDEX11 =
 "classzypp_1_1Capabilities.html#a53389294b01476030c3de577281c757d":[4,0,7,55,12],
 "classzypp_1_1Capabilities.html#a6f0845be9567819c10d229a5331d07f0":[3,0,10,64,10],
 "classzypp_1_1Capabilities.html#a6f0845be9567819c10d229a5331d07f0":[4,0,7,55,10],
-"classzypp_1_1Capabilities.html#a7f4492e1f2546fca3e92f4158fa1da58":[3,0,10,655],
+"classzypp_1_1Capabilities.html#a7f4492e1f2546fca3e92f4158fa1da58":[3,0,10,656],
 "classzypp_1_1Capabilities.html#a7f4492e1f2546fca3e92f4158fa1da58":[3,0,10,64,13],
 "classzypp_1_1Capabilities.html#a7f4492e1f2546fca3e92f4158fa1da58":[4,0,7,55,13],
 "classzypp_1_1Capabilities.html#a90657c3bf6a13bbdaccab6958d240f32":[3,0,10,64,2],
@@ -151,27 +168,27 @@ var NAVTREEINDEX11 =
 "classzypp_1_1Capability.html#a74e3ddb2da11d0fe0130c51ffa1c3daf":[4,0,7,56,53],
 "classzypp_1_1Capability.html#a7991361164226c745d9f3b909613daf6":[3,0,10,65,32],
 "classzypp_1_1Capability.html#a7991361164226c745d9f3b909613daf6":[4,0,7,56,32],
-"classzypp_1_1Capability.html#a7a5348ed20dd8b95a2438a4b89f06f62":[3,0,10,659],
+"classzypp_1_1Capability.html#a7a5348ed20dd8b95a2438a4b89f06f62":[3,0,10,660],
 "classzypp_1_1Capability.html#a7a5348ed20dd8b95a2438a4b89f06f62":[3,0,10,65,59],
 "classzypp_1_1Capability.html#a7a5348ed20dd8b95a2438a4b89f06f62":[4,0,7,56,59],
 "classzypp_1_1Capability.html#a7bbd8cb5f17c38179f5262927c96d5c6":[3,0,10,65,38],
 "classzypp_1_1Capability.html#a7bbd8cb5f17c38179f5262927c96d5c6":[4,0,7,56,38],
 "classzypp_1_1Capability.html#a825000f2bf718f4266aacb5c48da30f4":[3,0,10,65,26],
 "classzypp_1_1Capability.html#a825000f2bf718f4266aacb5c48da30f4":[4,0,7,56,26],
-"classzypp_1_1Capability.html#a859a7dbe3b6a35da0981d58dfbc29aee":[3,0,10,658],
+"classzypp_1_1Capability.html#a859a7dbe3b6a35da0981d58dfbc29aee":[3,0,10,659],
 "classzypp_1_1Capability.html#a859a7dbe3b6a35da0981d58dfbc29aee":[3,0,10,65,58],
 "classzypp_1_1Capability.html#a859a7dbe3b6a35da0981d58dfbc29aee":[4,0,7,56,58],
 "classzypp_1_1Capability.html#a866ea0297f39b6b31d8f2f8b7ebb0134":[3,0,10,65,55],
 "classzypp_1_1Capability.html#a866ea0297f39b6b31d8f2f8b7ebb0134":[4,0,7,56,55],
 "classzypp_1_1Capability.html#a8d686962e4430a524d6522ce7139173b":[3,0,10,65,49],
 "classzypp_1_1Capability.html#a8d686962e4430a524d6522ce7139173b":[4,0,7,56,49],
-"classzypp_1_1Capability.html#a902d11421218ecf4acd7ff9b1b924033":[3,0,10,660],
+"classzypp_1_1Capability.html#a902d11421218ecf4acd7ff9b1b924033":[3,0,10,661],
 "classzypp_1_1Capability.html#a902d11421218ecf4acd7ff9b1b924033":[3,0,10,65,60],
 "classzypp_1_1Capability.html#a902d11421218ecf4acd7ff9b1b924033":[4,0,7,56,60],
-"classzypp_1_1Capability.html#a93cb733439196b5618916dc0d8c92b45":[3,0,10,657],
+"classzypp_1_1Capability.html#a93cb733439196b5618916dc0d8c92b45":[3,0,10,658],
 "classzypp_1_1Capability.html#a93cb733439196b5618916dc0d8c92b45":[3,0,10,65,57],
 "classzypp_1_1Capability.html#a93cb733439196b5618916dc0d8c92b45":[4,0,7,56,57],
-"classzypp_1_1Capability.html#a961bf86b7ec66cb284f7a2f5e360c8ab":[3,0,10,656],
+"classzypp_1_1Capability.html#a961bf86b7ec66cb284f7a2f5e360c8ab":[3,0,10,657],
 "classzypp_1_1Capability.html#a961bf86b7ec66cb284f7a2f5e360c8ab":[3,0,10,65,56],
 "classzypp_1_1Capability.html#a961bf86b7ec66cb284f7a2f5e360c8ab":[4,0,7,56,56],
 "classzypp_1_1Capability.html#a97fda6a1ca77d3991b3312191f6fe310":[3,0,10,65,30],
@@ -228,26 +245,9 @@ var NAVTREEINDEX11 =
 "classzypp_1_1ChangelogEntry.html#a94778d700afd3f7857ee516f08ab81f4":[4,0,7,59,8],
 "classzypp_1_1ChangelogEntry.html#abce641f00331c86693f5c51bee024881":[3,0,10,68,0],
 "classzypp_1_1ChangelogEntry.html#abce641f00331c86693f5c51bee024881":[4,0,7,59,0],
-"classzypp_1_1ChangelogEntry.html#ad0b2f78c102d43141cbcf35b4e8220ea":[3,0,10,666],
+"classzypp_1_1ChangelogEntry.html#ad0b2f78c102d43141cbcf35b4e8220ea":[3,0,10,667],
 "classzypp_1_1ChangelogEntry.html#ad0b2f78c102d43141cbcf35b4e8220ea":[3,0,10,68,6],
 "classzypp_1_1ChangelogEntry.html#ad0b2f78c102d43141cbcf35b4e8220ea":[4,0,7,59,6],
 "classzypp_1_1ChangelogEntry.html#ad5befc4d2935110b4409162bf59e2490":[3,0,10,68,3],
-"classzypp_1_1ChangelogEntry.html#ad5befc4d2935110b4409162bf59e2490":[4,0,7,59,3],
-"classzypp_1_1ChangelogEntry.html#ae5218daf6b6b1ce02fb8d15039dcd4a1":[3,0,10,68,7],
-"classzypp_1_1ChangelogEntry.html#ae5218daf6b6b1ce02fb8d15039dcd4a1":[4,0,7,59,7],
-"classzypp_1_1ChangelogEntry.html#afb37d4888d24f154d1a9a47b83acd3db":[3,0,10,665],
-"classzypp_1_1ChangelogEntry.html#afb37d4888d24f154d1a9a47b83acd3db":[3,0,10,68,5],
-"classzypp_1_1ChangelogEntry.html#afb37d4888d24f154d1a9a47b83acd3db":[4,0,7,59,5],
-"classzypp_1_1CheckAccessDeleted.html":[3,0,10,69],
-"classzypp_1_1CheckAccessDeleted.html":[4,0,7,60],
-"classzypp_1_1CheckAccessDeleted.html#a3656a4238e99904b1144cee6c56e0abe":[3,0,10,69,6],
-"classzypp_1_1CheckAccessDeleted.html#a3656a4238e99904b1144cee6c56e0abe":[4,0,7,60,6],
-"classzypp_1_1CheckAccessDeleted.html#a462b34fd5cbab84297ec05d2c27fd737":[3,0,10,69,9],
-"classzypp_1_1CheckAccessDeleted.html#a462b34fd5cbab84297ec05d2c27fd737":[4,0,7,60,9],
-"classzypp_1_1CheckAccessDeleted.html#a4a07dbf9ea18a007513be6524ccc9d09":[3,0,10,69,5],
-"classzypp_1_1CheckAccessDeleted.html#a4a07dbf9ea18a007513be6524ccc9d09":[4,0,7,60,5],
-"classzypp_1_1CheckAccessDeleted.html#a4d0b49076cc3c8c435c326d6f2db8709":[3,0,10,69,11],
-"classzypp_1_1CheckAccessDeleted.html#a4d0b49076cc3c8c435c326d6f2db8709":[4,0,7,60,11],
-"classzypp_1_1CheckAccessDeleted.html#a506d3eeb6dce6618efefffb27bbbf835":[3,0,10,703],
-"classzypp_1_1CheckAccessDeleted.html#a506d3eeb6dce6618efefffb27bbbf835":[3,0,10,69,14]
+"classzypp_1_1ChangelogEntry.html#ad5befc4d2935110b4409162bf59e2490":[4,0,7,59,3]
 };
