@@ -1,6 +1,57 @@
 var NAVTREEINDEX30 =
 {
-"classzypp_1_1RepoStatus.html#a636732b1758b8c39f7f43fa50a759129":[3,0,10,733],
+"classzypp_1_1RepoManager.html#ad2e2ce1a883cb75b6adcb88208de18c5":[3,0,10,200,5],
+"classzypp_1_1RepoManager.html#ad2e2ce1a883cb75b6adcb88208de18c5":[4,0,7,191,5],
+"classzypp_1_1RepoManager.html#ad48cbda8fe55c118a211e35ee79132b5":[3,0,10,200,20],
+"classzypp_1_1RepoManager.html#ad48cbda8fe55c118a211e35ee79132b5":[4,0,7,191,20],
+"classzypp_1_1RepoManager.html#ad871de6adfbb08c1412022609e1cdb1d":[3,0,10,200,65],
+"classzypp_1_1RepoManager.html#ad871de6adfbb08c1412022609e1cdb1d":[4,0,7,191,65],
+"classzypp_1_1RepoManager.html#ad99b62fa3e88637c4b5e73a1ea2db3f7":[3,0,10,200,36],
+"classzypp_1_1RepoManager.html#ad99b62fa3e88637c4b5e73a1ea2db3f7":[4,0,7,191,36],
+"classzypp_1_1RepoManager.html#ade110800532620d8816879f7cf2242e6":[3,0,10,200,12],
+"classzypp_1_1RepoManager.html#ade110800532620d8816879f7cf2242e6":[4,0,7,191,12],
+"classzypp_1_1RepoManager.html#adf67fc64c5aa2c216bcd067de6fb05dd":[3,0,10,200,14],
+"classzypp_1_1RepoManager.html#adf67fc64c5aa2c216bcd067de6fb05dd":[4,0,7,191,14],
+"classzypp_1_1RepoManager.html#ae58e9b31d9c84a1b0e0e04fa709e63a4":[3,0,10,200,69],
+"classzypp_1_1RepoManager.html#ae58e9b31d9c84a1b0e0e04fa709e63a4":[4,0,7,191,69],
+"classzypp_1_1RepoManager.html#ae69db463cbc03aef151e3c07d04cef85":[3,0,10,200,39],
+"classzypp_1_1RepoManager.html#ae69db463cbc03aef151e3c07d04cef85":[4,0,7,191,39],
+"classzypp_1_1RepoManager.html#aeb0a5f2bfc0a4d7a2de0225e83309ab8":[3,0,10,200,42],
+"classzypp_1_1RepoManager.html#aeb0a5f2bfc0a4d7a2de0225e83309ab8":[4,0,7,191,42],
+"classzypp_1_1RepoManager.html#aee2998104f21fbfa1ecba1abf8322376":[3,0,10,200,34],
+"classzypp_1_1RepoManager.html#aee2998104f21fbfa1ecba1abf8322376":[4,0,7,191,34],
+"classzypp_1_1RepoManager.html#aefe4f8925d2e44fd89c73a9a60d1910b":[3,0,10,200,19],
+"classzypp_1_1RepoManager.html#aefe4f8925d2e44fd89c73a9a60d1910b":[4,0,7,191,19],
+"classzypp_1_1RepoManager.html#af196b0987675a4ad3579e9f51f3cb445":[3,0,10,200,27],
+"classzypp_1_1RepoManager.html#af196b0987675a4ad3579e9f51f3cb445":[4,0,7,191,27],
+"classzypp_1_1RepoManager.html#af281cb485d99cd424b7995ee537d9120":[3,0,10,200,66],
+"classzypp_1_1RepoManager.html#af281cb485d99cd424b7995ee537d9120":[4,0,7,191,66],
+"classzypp_1_1RepoManager.html#af63c4ecc81216a0f418760d5a342997d":[3,0,10,200,6],
+"classzypp_1_1RepoManager.html#af63c4ecc81216a0f418760d5a342997d":[4,0,7,191,6],
+"classzypp_1_1RepoManager.html#af953cd106add623a3a0f5ba6be992651":[3,0,10,200,26],
+"classzypp_1_1RepoManager.html#af953cd106add623a3a0f5ba6be992651":[4,0,7,191,26],
+"classzypp_1_1RepoManager.html#afc23894163b561e2be2ad5f868d8f21c":[3,0,10,200,41],
+"classzypp_1_1RepoManager.html#afc23894163b561e2be2ad5f868d8f21c":[4,0,7,191,41],
+"classzypp_1_1RepoManager.html#afdde02c0ccc48675c09255a4ce1d899d":[3,0,10,200,2],
+"classzypp_1_1RepoManager.html#afdde02c0ccc48675c09255a4ce1d899d":[4,0,7,191,2],
+"classzypp_1_1RepoStatus.html":[3,0,10,203],
+"classzypp_1_1RepoStatus.html":[4,0,7,194],
+"classzypp_1_1RepoStatus.html#a007aa8e6a6e13323528453eb9429b0b9":[3,0,10,203,11],
+"classzypp_1_1RepoStatus.html#a007aa8e6a6e13323528453eb9429b0b9":[4,0,7,194,11],
+"classzypp_1_1RepoStatus.html#a061fcd5a004dfc42138c50155a32d82d":[3,0,10,203,22],
+"classzypp_1_1RepoStatus.html#a061fcd5a004dfc42138c50155a32d82d":[4,0,7,194,22],
+"classzypp_1_1RepoStatus.html#a157d6403dd94646d47d069bdf5ee5307":[3,0,10,732],
+"classzypp_1_1RepoStatus.html#a157d6403dd94646d47d069bdf5ee5307":[3,0,10,203,18],
+"classzypp_1_1RepoStatus.html#a157d6403dd94646d47d069bdf5ee5307":[4,0,7,194,18],
+"classzypp_1_1RepoStatus.html#a177c96a017131ed01b64cb477e9f3d64":[3,0,10,203,10],
+"classzypp_1_1RepoStatus.html#a177c96a017131ed01b64cb477e9f3d64":[4,0,7,194,10],
+"classzypp_1_1RepoStatus.html#a4781566e8bbdbeb68eebadf15371733e":[3,0,10,203,14],
+"classzypp_1_1RepoStatus.html#a4781566e8bbdbeb68eebadf15371733e":[4,0,7,194,14],
+"classzypp_1_1RepoStatus.html#a47d2cd51d4a146b10b9951e6aa9fcb34":[3,0,10,203,5],
+"classzypp_1_1RepoStatus.html#a47d2cd51d4a146b10b9951e6aa9fcb34":[4,0,7,194,5],
+"classzypp_1_1RepoStatus.html#a490f458ede86e11cbae4dc331f7086fe":[3,0,10,203,13],
+"classzypp_1_1RepoStatus.html#a490f458ede86e11cbae4dc331f7086fe":[4,0,7,194,13],
+"classzypp_1_1RepoStatus.html#a636732b1758b8c39f7f43fa50a759129":[3,0,10,734],
 "classzypp_1_1RepoStatus.html#a636732b1758b8c39f7f43fa50a759129":[3,0,10,203,20],
 "classzypp_1_1RepoStatus.html#a636732b1758b8c39f7f43fa50a759129":[4,0,7,194,20],
 "classzypp_1_1RepoStatus.html#a6460d4db46d40c020f2cce6273491f95":[3,0,10,203,9],
@@ -23,10 +74,10 @@ var NAVTREEINDEX30 =
 "classzypp_1_1RepoStatus.html#aa79138e17d91e94b5f380e69506dcf7c":[4,0,7,194,4],
 "classzypp_1_1RepoStatus.html#abd845710e9a452df66c1b4ff0361f458":[3,0,10,203,12],
 "classzypp_1_1RepoStatus.html#abd845710e9a452df66c1b4ff0361f458":[4,0,7,194,12],
-"classzypp_1_1RepoStatus.html#ac851e09d94ae259a5001175c2b0efd18":[3,0,10,732],
+"classzypp_1_1RepoStatus.html#ac851e09d94ae259a5001175c2b0efd18":[3,0,10,733],
 "classzypp_1_1RepoStatus.html#ac851e09d94ae259a5001175c2b0efd18":[3,0,10,203,19],
 "classzypp_1_1RepoStatus.html#ac851e09d94ae259a5001175c2b0efd18":[4,0,7,194,19],
-"classzypp_1_1RepoStatus.html#ae34c1bdb2729555af72ec0fb3fc20acb":[3,0,10,734],
+"classzypp_1_1RepoStatus.html#ae34c1bdb2729555af72ec0fb3fc20acb":[3,0,10,735],
 "classzypp_1_1RepoStatus.html#ae34c1bdb2729555af72ec0fb3fc20acb":[3,0,10,203,21],
 "classzypp_1_1RepoStatus.html#ae34c1bdb2729555af72ec0fb3fc20acb":[4,0,7,194,21],
 "classzypp_1_1RepoStatus.html#ae3ad1eacafd0c08899d79a778e078daa":[3,0,10,203,7],
@@ -55,7 +106,7 @@ var NAVTREEINDEX30 =
 "classzypp_1_1Repository.html#a369f0ff3f2c4b2318d0818a0389dffeb":[4,0,7,193,26],
 "classzypp_1_1Repository.html#a3894a8ac279d05fef8695e84019bc5ca":[3,0,10,202,52],
 "classzypp_1_1Repository.html#a3894a8ac279d05fef8695e84019bc5ca":[4,0,7,193,52],
-"classzypp_1_1Repository.html#a3dbcbbc4c1813062caac9da0a40cbe59":[3,0,10,728],
+"classzypp_1_1Repository.html#a3dbcbbc4c1813062caac9da0a40cbe59":[3,0,10,729],
 "classzypp_1_1Repository.html#a3dbcbbc4c1813062caac9da0a40cbe59":[3,0,10,202,58],
 "classzypp_1_1Repository.html#a3dbcbbc4c1813062caac9da0a40cbe59":[4,0,7,193,58],
 "classzypp_1_1Repository.html#a42c5a433bb78d538f3b69755a870ae5f":[3,0,10,202,13],
@@ -76,7 +127,7 @@ var NAVTREEINDEX30 =
 "classzypp_1_1Repository.html#a6779f7b616521a4ecbb24b06bebd383b":[4,0,7,193,11],
 "classzypp_1_1Repository.html#a698e4ad4a4a3cad6bbee27dfe9a29c4a":[3,0,10,202,37],
 "classzypp_1_1Repository.html#a698e4ad4a4a3cad6bbee27dfe9a29c4a":[4,0,7,193,37],
-"classzypp_1_1Repository.html#a6dff15c2a9855b2b7513d385059811c7":[3,0,10,726],
+"classzypp_1_1Repository.html#a6dff15c2a9855b2b7513d385059811c7":[3,0,10,727],
 "classzypp_1_1Repository.html#a6dff15c2a9855b2b7513d385059811c7":[3,0,10,202,56],
 "classzypp_1_1Repository.html#a6dff15c2a9855b2b7513d385059811c7":[4,0,7,193,56],
 "classzypp_1_1Repository.html#a7090ffa1eb17613b93c60c2d9aa12d55":[3,0,10,202,54],
@@ -87,7 +138,7 @@ var NAVTREEINDEX30 =
 "classzypp_1_1Repository.html#a75675efadfc4138fe20d4acbdfb52f2f":[4,0,7,193,3],
 "classzypp_1_1Repository.html#a7987f029415bbc1a0b086131bf7c0168":[3,0,10,202,14],
 "classzypp_1_1Repository.html#a7987f029415bbc1a0b086131bf7c0168":[4,0,7,193,14],
-"classzypp_1_1Repository.html#a7ab110541a6559cfda68ee64ef19437e":[3,0,10,727],
+"classzypp_1_1Repository.html#a7ab110541a6559cfda68ee64ef19437e":[3,0,10,728],
 "classzypp_1_1Repository.html#a7ab110541a6559cfda68ee64ef19437e":[3,0,10,202,57],
 "classzypp_1_1Repository.html#a7ab110541a6559cfda68ee64ef19437e":[4,0,7,193,57],
 "classzypp_1_1Repository.html#a7addb3d0992530488cf87a4f02bb2a7b":[3,0,10,202,50],
@@ -124,12 +175,12 @@ var NAVTREEINDEX30 =
 "classzypp_1_1Repository.html#a9e2f17c8d3977d8fc29336f47db979ca":[4,0,7,193,51],
 "classzypp_1_1Repository.html#aa6768cbe788fce6044bc1cb1a4a1bc97":[3,0,10,202,18],
 "classzypp_1_1Repository.html#aa6768cbe788fce6044bc1cb1a4a1bc97":[4,0,7,193,18],
-"classzypp_1_1Repository.html#aaade5fa202adcd194b55c76c8826c53a":[3,0,10,730],
+"classzypp_1_1Repository.html#aaade5fa202adcd194b55c76c8826c53a":[3,0,10,731],
 "classzypp_1_1Repository.html#aaade5fa202adcd194b55c76c8826c53a":[3,0,10,202,60],
 "classzypp_1_1Repository.html#aaade5fa202adcd194b55c76c8826c53a":[4,0,7,193,60],
 "classzypp_1_1Repository.html#aaed55d1169a69962e57f3cd11572bfc1":[3,0,10,202,4],
 "classzypp_1_1Repository.html#aaed55d1169a69962e57f3cd11572bfc1":[4,0,7,193,4],
-"classzypp_1_1Repository.html#ab5d38bb04d15f11550158c19f4c9fa9c":[3,0,10,729],
+"classzypp_1_1Repository.html#ab5d38bb04d15f11550158c19f4c9fa9c":[3,0,10,730],
 "classzypp_1_1Repository.html#ab5d38bb04d15f11550158c19f4c9fa9c":[3,0,10,202,59],
 "classzypp_1_1Repository.html#ab5d38bb04d15f11550158c19f4c9fa9c":[4,0,7,193,59],
 "classzypp_1_1Repository.html#ab624346b583a6b020e08b568cd6f1765":[3,0,10,202,47],
@@ -198,56 +249,5 @@ var NAVTREEINDEX30 =
 "classzypp_1_1ResKind.html#a35ba510f07b2ecf638aaeeffe0bd711b":[4,0,7,196,15],
 "classzypp_1_1ResKind.html#a4bc7069af6ffaefb1a1880eb9ab4f31a":[3,0,10,205,5],
 "classzypp_1_1ResKind.html#a4bc7069af6ffaefb1a1880eb9ab4f31a":[4,0,7,196,5],
-"classzypp_1_1ResKind.html#a636cc9bd9564115576808c5630586ca6":[3,0,10,205,9],
-"classzypp_1_1ResKind.html#a636cc9bd9564115576808c5630586ca6":[4,0,7,196,9],
-"classzypp_1_1ResKind.html#a651c21357686882b092fd0dc6fae38b0":[3,0,10,205,13],
-"classzypp_1_1ResKind.html#a651c21357686882b092fd0dc6fae38b0":[4,0,7,196,13],
-"classzypp_1_1ResKind.html#a6a195f7cf190932b381e41e0e8334601":[3,0,10,735],
-"classzypp_1_1ResKind.html#a6a195f7cf190932b381e41e0e8334601":[3,0,10,205,12],
-"classzypp_1_1ResKind.html#a6a195f7cf190932b381e41e0e8334601":[4,0,7,196,12],
-"classzypp_1_1ResKind.html#a751a7d76f32f6250e9e2e4dee4491103":[3,0,10,205,14],
-"classzypp_1_1ResKind.html#a751a7d76f32f6250e9e2e4dee4491103":[4,0,7,196,14],
-"classzypp_1_1ResKind.html#a7f3e7818effe3c7ac2284f74eb941310":[3,0,10,205,8],
-"classzypp_1_1ResKind.html#a7f3e7818effe3c7ac2284f74eb941310":[4,0,7,196,8],
-"classzypp_1_1ResKind.html#a80f96169b0d53a3c2af12ca9b038c46b":[3,0,10,205,11],
-"classzypp_1_1ResKind.html#a80f96169b0d53a3c2af12ca9b038c46b":[4,0,7,196,11],
-"classzypp_1_1ResKind.html#a96b738b2610845cdfef5c5a5cdc4b1da":[3,0,10,205,20],
-"classzypp_1_1ResKind.html#a96b738b2610845cdfef5c5a5cdc4b1da":[4,0,7,196,20],
-"classzypp_1_1ResKind.html#abd02d186259789f960500054aa9373b9":[3,0,10,205,3],
-"classzypp_1_1ResKind.html#abd02d186259789f960500054aa9373b9":[4,0,7,196,3],
-"classzypp_1_1ResKind.html#ac713ea58c304a14c5577aba3c3552125":[3,0,10,205,6],
-"classzypp_1_1ResKind.html#ac713ea58c304a14c5577aba3c3552125":[4,0,7,196,6],
-"classzypp_1_1ResKind.html#ad01ef58e145fd8330d09ce14733d359d":[3,0,10,205,0],
-"classzypp_1_1ResKind.html#ad01ef58e145fd8330d09ce14733d359d":[4,0,7,196,0],
-"classzypp_1_1ResKind.html#ad3eb620b27161ef879a14cb1fdc83445":[3,0,10,205,10],
-"classzypp_1_1ResKind.html#ad3eb620b27161ef879a14cb1fdc83445":[4,0,7,196,10],
-"classzypp_1_1ResKind.html#adc7913afcb22d441693d7d219b9edb41":[3,0,10,205,7],
-"classzypp_1_1ResKind.html#adc7913afcb22d441693d7d219b9edb41":[4,0,7,196,7],
-"classzypp_1_1ResObject.html":[3,0,10,206],
-"classzypp_1_1ResObject.html":[4,0,7,197],
-"classzypp_1_1ResObject.html#a1eb3a4d6c6cd0a17ee490728df3f5e08":[3,0,10,206,7],
-"classzypp_1_1ResObject.html#a1eb3a4d6c6cd0a17ee490728df3f5e08":[4,0,7,197,7],
-"classzypp_1_1ResObject.html#a460bb68f123b4d2af0c6fed8769d5b13":[3,0,10,206,3],
-"classzypp_1_1ResObject.html#a460bb68f123b4d2af0c6fed8769d5b13":[4,0,7,197,3],
-"classzypp_1_1ResObject.html#a4f730f208546ca0df49461b112c0ecf7":[3,0,10,206,0],
-"classzypp_1_1ResObject.html#a4f730f208546ca0df49461b112c0ecf7":[4,0,7,197,0],
-"classzypp_1_1ResObject.html#a585baf1744f46d4715c0bbb2538cd83d":[3,0,10,206,11],
-"classzypp_1_1ResObject.html#a585baf1744f46d4715c0bbb2538cd83d":[4,0,7,197,11],
-"classzypp_1_1ResObject.html#a70547cd418598f51373455a7c4034250":[3,0,10,206,8],
-"classzypp_1_1ResObject.html#a70547cd418598f51373455a7c4034250":[4,0,7,197,8],
-"classzypp_1_1ResObject.html#a93808273a8f027ea73ceeefee3d98f46":[3,0,10,206,4],
-"classzypp_1_1ResObject.html#a93808273a8f027ea73ceeefee3d98f46":[4,0,7,197,4],
-"classzypp_1_1ResObject.html#ac1775b5178fb4920fe4bb84abf144f37":[3,0,10,206,2],
-"classzypp_1_1ResObject.html#ac1775b5178fb4920fe4bb84abf144f37":[4,0,7,197,2],
-"classzypp_1_1ResObject.html#accb5fc40e489ad9e17d368b0921e50a4":[3,0,10,736],
-"classzypp_1_1ResObject.html#accb5fc40e489ad9e17d368b0921e50a4":[3,0,10,206,12],
-"classzypp_1_1ResObject.html#accb5fc40e489ad9e17d368b0921e50a4":[4,0,7,197,12],
-"classzypp_1_1ResObject.html#ad110b911c4d5e9b6f83b35c608d35b7c":[3,0,10,206,9],
-"classzypp_1_1ResObject.html#ad110b911c4d5e9b6f83b35c608d35b7c":[4,0,7,197,9],
-"classzypp_1_1ResObject.html#adb11be879e8c33b622f990f02daa986d":[3,0,10,206,6],
-"classzypp_1_1ResObject.html#adb11be879e8c33b622f990f02daa986d":[4,0,7,197,6],
-"classzypp_1_1ResObject.html#ae1e58c498181cd7b28ac3f743c41573e":[3,0,10,206,10],
-"classzypp_1_1ResObject.html#ae1e58c498181cd7b28ac3f743c41573e":[4,0,7,197,10],
-"classzypp_1_1ResObject.html#aedf1edf1776148203e97c075d3f3cc3c":[3,0,10,206,5],
-"classzypp_1_1ResObject.html#aedf1edf1776148203e97c075d3f3cc3c":[4,0,7,197,5]
+"classzypp_1_1ResKind.html#a636cc9bd9564115576808c5630586ca6":[3,0,10,205,9]
 };
