@@ -1,5 +1,56 @@
 var NAVTREEINDEX43 =
 {
+"classzypp_1_1filesystem_1_1Glob.html":[3,0,10,10,2],
+"classzypp_1_1filesystem_1_1Glob.html":[4,0,7,9,2],
+"classzypp_1_1filesystem_1_1Glob.html#a09bcdd9a421dd7ade5b30cfa98bcee1b":[3,0,10,10,2,26],
+"classzypp_1_1filesystem_1_1Glob.html#a09bcdd9a421dd7ade5b30cfa98bcee1b":[4,0,7,9,2,26],
+"classzypp_1_1filesystem_1_1Glob.html#a0cc60091cfb6155f93019180d053d79b":[3,0,10,10,2,2],
+"classzypp_1_1filesystem_1_1Glob.html#a0cc60091cfb6155f93019180d053d79b":[4,0,7,9,2,2],
+"classzypp_1_1filesystem_1_1Glob.html#a13f1e28751152f0eaf6841dd6b86a064":[3,0,10,10,2,18],
+"classzypp_1_1filesystem_1_1Glob.html#a13f1e28751152f0eaf6841dd6b86a064":[4,0,7,9,2,18],
+"classzypp_1_1filesystem_1_1Glob.html#a29a71461dd4c15fb130fff63ee9197d8":[3,0,10,10,2,31],
+"classzypp_1_1filesystem_1_1Glob.html#a29a71461dd4c15fb130fff63ee9197d8":[4,0,7,9,2,31],
+"classzypp_1_1filesystem_1_1Glob.html#a35132e6f83c54cf8f41983c10e03b03f":[3,0,10,10,2,16],
+"classzypp_1_1filesystem_1_1Glob.html#a35132e6f83c54cf8f41983c10e03b03f":[4,0,7,9,2,16],
+"classzypp_1_1filesystem_1_1Glob.html#a393268e19f1134d9230c34ca7f5f9ffe":[3,0,10,10,2,12],
+"classzypp_1_1filesystem_1_1Glob.html#a393268e19f1134d9230c34ca7f5f9ffe":[4,0,7,9,2,12],
+"classzypp_1_1filesystem_1_1Glob.html#a429140f94663445bd5374047c3803d92":[3,0,10,10,2,11],
+"classzypp_1_1filesystem_1_1Glob.html#a429140f94663445bd5374047c3803d92":[4,0,7,9,2,11],
+"classzypp_1_1filesystem_1_1Glob.html#a4b09fa6a38ad70baf063665736605186":[3,0,10,10,2,4],
+"classzypp_1_1filesystem_1_1Glob.html#a4b09fa6a38ad70baf063665736605186":[4,0,7,9,2,4],
+"classzypp_1_1filesystem_1_1Glob.html#a54ee38176ac61752c156fb41ff08ce69":[3,0,10,10,2,19],
+"classzypp_1_1filesystem_1_1Glob.html#a54ee38176ac61752c156fb41ff08ce69":[4,0,7,9,2,19],
+"classzypp_1_1filesystem_1_1Glob.html#a55bc7be81b23e2770109e99e02ede381":[3,0,10,10,2,23],
+"classzypp_1_1filesystem_1_1Glob.html#a55bc7be81b23e2770109e99e02ede381":[4,0,7,9,2,23],
+"classzypp_1_1filesystem_1_1Glob.html#a56ca0ae1c7afa7ec2bc636a68cd3afcc":[3,0,10,10,2,9],
+"classzypp_1_1filesystem_1_1Glob.html#a56ca0ae1c7afa7ec2bc636a68cd3afcc":[4,0,7,9,2,9],
+"classzypp_1_1filesystem_1_1Glob.html#a66a1eb3be39e1e26cf42d5c4c38048f8":[3,0,10,10,2,20],
+"classzypp_1_1filesystem_1_1Glob.html#a66a1eb3be39e1e26cf42d5c4c38048f8":[4,0,7,9,2,20],
+"classzypp_1_1filesystem_1_1Glob.html#a6af22dbde63340867ed3ca8bd0fd7a54":[3,0,10,10,2,10],
+"classzypp_1_1filesystem_1_1Glob.html#a6af22dbde63340867ed3ca8bd0fd7a54":[4,0,7,9,2,10],
+"classzypp_1_1filesystem_1_1Glob.html#a6dfba37b6a3739a76f16357aaa95478f":[3,0,10,10,2,24],
+"classzypp_1_1filesystem_1_1Glob.html#a6dfba37b6a3739a76f16357aaa95478f":[4,0,7,9,2,24],
+"classzypp_1_1filesystem_1_1Glob.html#a76ca385ae65a1c1f2d6838ea9265daa0":[3,0,10,10,2,3],
+"classzypp_1_1filesystem_1_1Glob.html#a76ca385ae65a1c1f2d6838ea9265daa0":[4,0,7,9,2,3],
+"classzypp_1_1filesystem_1_1Glob.html#a76ca385ae65a1c1f2d6838ea9265daa0a0e384f667b7bdc2b5df960f4175d6801":[3,0,10,10,2,3,10],
+"classzypp_1_1filesystem_1_1Glob.html#a76ca385ae65a1c1f2d6838ea9265daa0a0e384f667b7bdc2b5df960f4175d6801":[4,0,7,9,2,3,10],
+"classzypp_1_1filesystem_1_1Glob.html#a76ca385ae65a1c1f2d6838ea9265daa0a297ca8875199f83b3821147eaa4e3670":[3,0,10,10,2,3,7],
+"classzypp_1_1filesystem_1_1Glob.html#a76ca385ae65a1c1f2d6838ea9265daa0a297ca8875199f83b3821147eaa4e3670":[4,0,7,9,2,3,7],
+"classzypp_1_1filesystem_1_1Glob.html#a76ca385ae65a1c1f2d6838ea9265daa0a3bc5a3ef66824558ee6e052e18bb7275":[3,0,10,10,2,3,5],
+"classzypp_1_1filesystem_1_1Glob.html#a76ca385ae65a1c1f2d6838ea9265daa0a3bc5a3ef66824558ee6e052e18bb7275":[4,0,7,9,2,3,5],
+"classzypp_1_1filesystem_1_1Glob.html#a76ca385ae65a1c1f2d6838ea9265daa0a4e21d6fa9882b328cbf3ff22e474d412":[3,0,10,10,2,3,3],
+"classzypp_1_1filesystem_1_1Glob.html#a76ca385ae65a1c1f2d6838ea9265daa0a4e21d6fa9882b328cbf3ff22e474d412":[4,0,7,9,2,3,3],
+"classzypp_1_1filesystem_1_1Glob.html#a76ca385ae65a1c1f2d6838ea9265daa0a573cf7911986671bf5fdb5b6de371ecf":[3,0,10,10,2,3,4],
+"classzypp_1_1filesystem_1_1Glob.html#a76ca385ae65a1c1f2d6838ea9265daa0a573cf7911986671bf5fdb5b6de371ecf":[4,0,7,9,2,3,4],
+"classzypp_1_1filesystem_1_1Glob.html#a76ca385ae65a1c1f2d6838ea9265daa0a73df01c7f58a0e06854b2cbd8d2c9aa4":[3,0,10,10,2,3,8],
+"classzypp_1_1filesystem_1_1Glob.html#a76ca385ae65a1c1f2d6838ea9265daa0a73df01c7f58a0e06854b2cbd8d2c9aa4":[4,0,7,9,2,3,8],
+"classzypp_1_1filesystem_1_1Glob.html#a76ca385ae65a1c1f2d6838ea9265daa0a783332b0bf23373f98f8055de1a26351":[3,0,10,10,2,3,9],
+"classzypp_1_1filesystem_1_1Glob.html#a76ca385ae65a1c1f2d6838ea9265daa0a783332b0bf23373f98f8055de1a26351":[4,0,7,9,2,3,9],
+"classzypp_1_1filesystem_1_1Glob.html#a76ca385ae65a1c1f2d6838ea9265daa0a9a2f98cb002c27cfbf566b7964357fb1":[3,0,10,10,2,3,1],
+"classzypp_1_1filesystem_1_1Glob.html#a76ca385ae65a1c1f2d6838ea9265daa0a9a2f98cb002c27cfbf566b7964357fb1":[4,0,7,9,2,3,1],
+"classzypp_1_1filesystem_1_1Glob.html#a76ca385ae65a1c1f2d6838ea9265daa0abf6bbd6dd02938a1e30326ffba27a382":[3,0,10,10,2,3,2],
+"classzypp_1_1filesystem_1_1Glob.html#a76ca385ae65a1c1f2d6838ea9265daa0abf6bbd6dd02938a1e30326ffba27a382":[4,0,7,9,2,3,2],
+"classzypp_1_1filesystem_1_1Glob.html#a76ca385ae65a1c1f2d6838ea9265daa0ac9f969eeb405475e96fa2e4c9532cf14":[3,0,10,10,2,3,0],
 "classzypp_1_1filesystem_1_1Glob.html#a76ca385ae65a1c1f2d6838ea9265daa0ac9f969eeb405475e96fa2e4c9532cf14":[4,0,7,9,2,3,0],
 "classzypp_1_1filesystem_1_1Glob.html#a76ca385ae65a1c1f2d6838ea9265daa0ae617216835eab11dd2fc6930d98fe353":[3,0,10,10,2,3,6],
 "classzypp_1_1filesystem_1_1Glob.html#a76ca385ae65a1c1f2d6838ea9265daa0ae617216835eab11dd2fc6930d98fe353":[4,0,7,9,2,3,6],
@@ -198,56 +249,5 @@ var NAVTREEINDEX43 =
 "classzypp_1_1filesystem_1_1PathInfo.html#ad38e533ced074974c95d8ea4b5864137":[3,0,10,10,3,7],
 "classzypp_1_1filesystem_1_1PathInfo.html#ad38e533ced074974c95d8ea4b5864137":[4,0,7,9,3,7],
 "classzypp_1_1filesystem_1_1PathInfo.html#ad8ace20c71d1f84682e39230840c2e6c":[3,0,10,10,3,78],
-"classzypp_1_1filesystem_1_1PathInfo.html#ad8ace20c71d1f84682e39230840c2e6c":[4,0,7,9,3,78],
-"classzypp_1_1filesystem_1_1PathInfo.html#ad8d998c4bd37d76d953c48b1c3ca2c29":[3,0,10,10,3,44],
-"classzypp_1_1filesystem_1_1PathInfo.html#ad8d998c4bd37d76d953c48b1c3ca2c29":[4,0,7,9,3,44],
-"classzypp_1_1filesystem_1_1PathInfo.html#adda3eec67fe734365fde92ef9b284b4d":[3,0,10,10,3,24],
-"classzypp_1_1filesystem_1_1PathInfo.html#adda3eec67fe734365fde92ef9b284b4d":[4,0,7,9,3,24],
-"classzypp_1_1filesystem_1_1PathInfo.html#ade23e0a8fdbcf559b85c0526bf9ed605":[3,0,10,10,3,65],
-"classzypp_1_1filesystem_1_1PathInfo.html#ade23e0a8fdbcf559b85c0526bf9ed605":[4,0,7,9,3,65],
-"classzypp_1_1filesystem_1_1PathInfo.html#ae04bebec092f91506eb7d1e51d937e16":[3,0,10,10,3,35],
-"classzypp_1_1filesystem_1_1PathInfo.html#ae04bebec092f91506eb7d1e51d937e16":[4,0,7,9,3,35],
-"classzypp_1_1filesystem_1_1PathInfo.html#ae482a753a5c96a840744909e605bb63a":[3,0,10,10,3,39],
-"classzypp_1_1filesystem_1_1PathInfo.html#ae482a753a5c96a840744909e605bb63a":[4,0,7,9,3,39],
-"classzypp_1_1filesystem_1_1PathInfo.html#ae7126f8792cb2ddfcdeb595d19cfbed7":[3,0,10,10,3,62],
-"classzypp_1_1filesystem_1_1PathInfo.html#ae7126f8792cb2ddfcdeb595d19cfbed7":[4,0,7,9,3,62],
-"classzypp_1_1filesystem_1_1PathInfo.html#aec501c34dd60f9b7e963e3c1a5c5e0ee":[3,0,10,10,3,30],
-"classzypp_1_1filesystem_1_1PathInfo.html#aec501c34dd60f9b7e963e3c1a5c5e0ee":[4,0,7,9,3,30],
-"classzypp_1_1filesystem_1_1PathInfo.html#af3df5c570fe783054fe10a80bfaaa885":[3,0,10,10,3,15],
-"classzypp_1_1filesystem_1_1PathInfo.html#af3df5c570fe783054fe10a80bfaaa885":[4,0,7,9,3,15],
-"classzypp_1_1filesystem_1_1PathInfo.html#afdaac2662fb44fc2c758bdbda470d64e":[3,0,10,10,3,10],
-"classzypp_1_1filesystem_1_1PathInfo.html#afdaac2662fb44fc2c758bdbda470d64e":[4,0,7,9,3,10],
-"classzypp_1_1filesystem_1_1PathInfo.html#afe38348dcabd7d0bdd76169bb5cc532b":[3,0,10,10,3,13],
-"classzypp_1_1filesystem_1_1PathInfo.html#afe38348dcabd7d0bdd76169bb5cc532b":[4,0,7,9,3,13],
-"classzypp_1_1filesystem_1_1Pathname.html":[3,0,10,10,4],
-"classzypp_1_1filesystem_1_1Pathname.html":[4,0,7,9,4],
-"classzypp_1_1filesystem_1_1Pathname.html#a002defe2b68e3b5eaa1db8e58cad680a":[3,0,10,10,4,28],
-"classzypp_1_1filesystem_1_1Pathname.html#a002defe2b68e3b5eaa1db8e58cad680a":[4,0,7,9,4,28],
-"classzypp_1_1filesystem_1_1Pathname.html#a0a7eb7b7a43160283ce4d354e04d53b6":[3,0,10,10,4,9],
-"classzypp_1_1filesystem_1_1Pathname.html#a0a7eb7b7a43160283ce4d354e04d53b6":[4,0,7,9,4,9],
-"classzypp_1_1filesystem_1_1Pathname.html#a1114035054f85b92ed389e33c0b42bb9":[3,0,10,10,4,35],
-"classzypp_1_1filesystem_1_1Pathname.html#a1114035054f85b92ed389e33c0b42bb9":[4,0,7,9,4,35],
-"classzypp_1_1filesystem_1_1Pathname.html#a128db32a95f75617ad4b5da5f9caac43":[3,0,10,10,4,36],
-"classzypp_1_1filesystem_1_1Pathname.html#a128db32a95f75617ad4b5da5f9caac43":[4,0,7,9,4,36],
-"classzypp_1_1filesystem_1_1Pathname.html#a15a542166ceff28c02d85d8a1874e4fd":[3,0,10,10,4,3],
-"classzypp_1_1filesystem_1_1Pathname.html#a15a542166ceff28c02d85d8a1874e4fd":[4,0,7,9,4,3],
-"classzypp_1_1filesystem_1_1Pathname.html#a1b2ef1832b682e0142661312b91aa3f7":[3,0,10,10,72],
-"classzypp_1_1filesystem_1_1Pathname.html#a1b2ef1832b682e0142661312b91aa3f7":[3,0,10,10,4,44],
-"classzypp_1_1filesystem_1_1Pathname.html#a1b2ef1832b682e0142661312b91aa3f7":[4,0,7,9,4,44],
-"classzypp_1_1filesystem_1_1Pathname.html#a1efaf869d2b914f0d6cded79039a488c":[3,0,10,10,4,6],
-"classzypp_1_1filesystem_1_1Pathname.html#a1efaf869d2b914f0d6cded79039a488c":[4,0,7,9,4,6],
-"classzypp_1_1filesystem_1_1Pathname.html#a20fb2ab3b6dd7f6fc2ef1470ccedfbd8":[3,0,10,10,4,21],
-"classzypp_1_1filesystem_1_1Pathname.html#a20fb2ab3b6dd7f6fc2ef1470ccedfbd8":[4,0,7,9,4,21],
-"classzypp_1_1filesystem_1_1Pathname.html#a35992cbd3cedefe981a1c44a04e5621e":[3,0,10,10,4,38],
-"classzypp_1_1filesystem_1_1Pathname.html#a35992cbd3cedefe981a1c44a04e5621e":[4,0,7,9,4,38],
-"classzypp_1_1filesystem_1_1Pathname.html#a3f234226fbec1f1cae3ae23d1259df3a":[3,0,10,10,4,4],
-"classzypp_1_1filesystem_1_1Pathname.html#a3f234226fbec1f1cae3ae23d1259df3a":[4,0,7,9,4,4],
-"classzypp_1_1filesystem_1_1Pathname.html#a4124f90f3058950a0947d7c2482796f9":[3,0,10,10,4,32],
-"classzypp_1_1filesystem_1_1Pathname.html#a4124f90f3058950a0947d7c2482796f9":[4,0,7,9,4,32],
-"classzypp_1_1filesystem_1_1Pathname.html#a5906250cac5f91cc2ff1e6110a5bdd9f":[3,0,10,10,4,27],
-"classzypp_1_1filesystem_1_1Pathname.html#a5906250cac5f91cc2ff1e6110a5bdd9f":[4,0,7,9,4,27],
-"classzypp_1_1filesystem_1_1Pathname.html#a5bf4121a6cc6dd468b3d07e803fb77db":[3,0,10,10,4,7],
-"classzypp_1_1filesystem_1_1Pathname.html#a5bf4121a6cc6dd468b3d07e803fb77db":[4,0,7,9,4,7],
-"classzypp_1_1filesystem_1_1Pathname.html#a5cc68841952d6d462a1212119356da20":[3,0,10,10,4,20],
-"classzypp_1_1filesystem_1_1Pathname.html#a5cc68841952d6d462a1212119356da20":[4,0,7,9,4,20]
+"classzypp_1_1filesystem_1_1PathInfo.html#ad8ace20c71d1f84682e39230840c2e6c":[4,0,7,9,3,78]
 };
